BINDING_HEADER_BIDMEHEADER = "BidMe Bid Tracker";

-- added comment
local options = { 
    type='group',
    args = {
        show = {
            type = 'execute',
            name = 'Toggle Window',
            desc = 'Show / Hide Window',
            func = "ToggleShow",
        },
        pause = {
            type = 'execute',
            name = 'Pause Bidding',
            desc = 'Toggles a pause in the bidding sequence',
            func = "TogglePauseBidding",
        },
       advance_bidding = {
            type = 'execute',
            name = 'Advance Bidding Stage',
            desc = 'Advances to the next bidding stage',
            func = "AdvanceBiddingStage",
        },        
        auto_advance = {
            type = 'toggle',
            name = 'Auto Advance',
            desc = 'Toggles the auto advancement of the bidding sequence',
            get = "IsAutoAdvance",
            set = "ToggleAutoAdvance",
        },
        whisper_response = {
            type = 'toggle',
            name = 'Respond To Bidder.',
            desc = 'Toggles the response whisper to the bidder',
            get = "IsWhisperResponse",
            set = "ToggleWhisperResponse",
        },
		abort = {
            type = 'execute',
            name = 'Abort Bids.',
            desc = 'Cancels the current bidding process.',
            func = "CancelBidding"
        },        
		countdown_timer = {
		    type = 'text',
		    name = "Countdown Timer",
		    desc = "Amount of time to wait before starting closing sequence (in seconds)",
		    usage = "",
		    get = "GetCountdownTimer",
		    set = "SetCountdownTimer",
		},        
     }
}


BidMe = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")
BidMe:RegisterChatCommand("/bidme", "/bm", options)

---------------------------------------------------------------------------
BidMe:RegisterDB("BidMeDB", "BidMeDBPC")
BidMe:RegisterDefaults("profile", {
-- Predefined settings
-- Send a response on a whisper to the bidder that it was received
	whisper_response = false,
-- How long we are going to give count downs
	countdown_timer = 20,
	pause = false,
	auto_advance = false,

} )


---------------------------------------------------------------------------

function BidMe:OnInitialize()
    -- Called when the addon is loaded
	BidMe:Print("BidMe Bid Tracker Loaded")
	
	-- set out the saved variables if they dont exist
	if BidMe.db.profile.countdown_timer == "" then
		BidMe.db.profile.countdown_timer = 20
	end
	if BidMe.db.profile.auto_advance == "" then
		BidMe.db.profile.auto_advance = true
	end
	if BidMe.db.profile.whisper_response == "" then
		BidMe.db.profile.whisper_response = false
	end

	BidMe:ResetVariables()
	
end

function BidMe:OnEnable()
    -- Called when the addon is enabled
	BidMe:Print("BidMe Bid Tracker Enabled")
	BidMe:Print("Use /bidme for options list")	

	BidMe:RegisterEvent("CHAT_MSG_WHISPER")
	BidMe:RegisterEvent("CHAT_MSG_RAID")
	BidMe:RegisterEvent("CHAT_MSG_PARTY")	
	BidMe:RegisterEvent("CHAT_MSG_SAY")		
	BidMe:RegisterEvent("CHAT_MSG_RAID_LEADER")	
	BidMe:RegisterEvent("CHAT_MSG_SYSTEM")		

	BidMe:RegisterEvent("BIDME_RUN_COUNTDOWN")
	--self:RegisterEvent("BIDME_CLOSE_BID")
end

function BidMe:OnDisable()
    -- Called when the addon is disabled
	BidMe:Print("BidMe Bid Tracker Disabled")
end

function BidMe:ResetVariables()

	BidMe.item_link = ""
	BidMe.active = false
	BidMe.close_bids_in = 10

	-- Track the level in which the bidding is currently at
	-- 3 - Primary
	-- 2 - Initiate / Offspec
	-- 1 - Open
	-- 0 - Rolls
	BidMe.bid_level = 3 

	-- flag to know when to listen for rolls
	BidMe.enable_rolls = false	
	-- used to track the highest roll so far
	BidMe.ROLL_PATTERN = "(.+) rolls (%d+) %((%d+)%-(%d+)%)" --hopefully fixes the  character problems
	BidMe.roll_list = {}
	BidMe.recorded_roll_list = {}
	BidMe.bid_list = {}

end

function BidMe:AnnouceWhere ()
	if GetNumRaidMembers() > 0 then
		return "RAID"
	elseif GetNumPartyMembers() > 0 then
		return "PARTY"
	else
		return "SAY"
	end	
end


function BidMe:SendMessage(arg1)
	local message = arg1
	local announce_to = BidMe:AnnouceWhere()
	SendChatMessage(message, announce_to)
end

function BidMe:SendWhisper(arg1, arg2)
	local message = arg1
	local author = arg2
	SendChatMessage(message, "WHISPER","Common",author)
end

---------------------------------------------------------------------------
-- Setting Functions
function BidMe:ToggleShow()
	if BidMeFrame:IsVisible() then
		BidMeFrame:Hide()
	else
		if BidMe.db.profile.auto_advance == true then
			msg = "Auto"
		else
			msg = "Manual"
		end

		BidMetxtStatus:SetText("|cff00ff00Mode: "..msg.."|r");	
		BidMeFrame:Show()
	end
end

function BidMe:TogglePauseBidding()
	-- make sure we are bidding
	if not BidMe.db.profile.auto_advance then
		BidMe:Print("** YOU CAN NOT PAUSE MANUAL ADVANCEMENT BIDDING **")
		return
	end
	if not BidMe.active then
		BidMe:Print("** NO ACTIVE BIDDING SEQUENCE **")		
		return
	end
	if BidMe.active and BidMe.db.profile.auto_advance then
		BidMe.db.profile.pause = not BidMe.db.profile.pause
		if BidMe.db.profile.pause then
			-- we have paused the bidding
			BidMe:Print("** BID SEQUENCE PAUSED **")
			BidMe:SendMessage("** BID SEQUENCE PAUSED **")
			BidMe:CancelAllScheduledEvents()
		else
			-- we have restarted the bidding
			BidMe:Print("** BID SEQUENCE RESTARTED **")
			BidMe:SendMessage("** BID SEQUENCE RESTARTED **")
			BidMe.close_bids_in = 10
			BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))
		end	
	end
end
	

function BidMe:SetCountdownTimer(value)
	BidMe.db.profile.countdown_timer = value 
end

function BidMe:GetCountdownTimer()
	return BidMe.db.profile.countdown_timer
end

function BidMe:IsAutoAdvance()
	return BidMe.db.profile.auto_advance
end

function BidMe:ToggleAutoAdvance()
	BidMe.db.profile.auto_advance =  not BidMe.db.profile.auto_advance
end

function BidMe:IsWhisperResponse()
	return BidMe.db.profile.whisper_response
end

function BidMe:ToggleWhisperResponse()
	BidMe.db.profile.whisper_response =  not BidMe.db.profile.whisper_response
end

function BidMe:CancelBidding()
	if BidMe.active then
		-- DEFAULT_CHAT_FRAME:AddMessage("** BID SEQUENCE ABORTED **", 1.0, 0.0, 0.0)
		BidMe:SendMessage("** BID SEQUENCE ABORTED **")
		BidMe:Print("** BID SEQUENCE ABORTED **")

		BidMe:CancelAllScheduledEvents()
		BidMe.ResetVariables()
	end
end

function BidMe:AdvanceBiddingStage()
	if BidMe.active then
		BidMe:CancelAllScheduledEvents()
		BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", 0)
	else
		BidMe:Print("** NO ACTIVE BIDDING SEQUENCE **")		
	end

end

-- End of Setting Functions
---------------------------------------------------------------------------

---------------------------------------------------------------------------
-- Chat Functions

function BidMe:ProcessChatMessage(arg1, arg2, arg3) 
	
	local message = arg1
	local author = arg2
	local language = arg3
	
	if author == UnitName("player") and strlower(strsub(message, 1, 6)) == "!bidme" then
		
		if not BidMeFrame:IsVisible() then
			BidMe:ToggleShow()
		end
		
		-- make sure bidding is not paused right now.
		BidMe.db.profile.pause = false
		-- set the default values again incase they were left from before
		local sName, sLink, iRarity, iLevel, iMinLevel, sType, sSubType, iStackCount = GetItemInfo(message);
		
		
		
		BidMe:ResetVariables()
		-- reset the bidding window
		ScrollChildHTML:SetText("");
		ScrollFrame:UpdateScrollChildRect();
		
		BidMe.active = true
		BidMe.item_link = sLink
				
		BidMe:SendMessage("** PRIMARY BIDS **.") 
		BidMetxtBidLevel:SetText("PRIMARY")
		if BidMe.db.profile.auto_advance then
			BidMe:Print("** AUTO MODE **")
		else
			BidMe:Print("** MANUAL MODE **")
		end
		--if(BidMe.db.profile.force_bid_command) then
		--	BidMe:SendMessage("Whisper me !bid <dkp amount> to bid.") 
		--end
		if BidMe.db.profile.auto_advance then
			BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))
		end
--		SendChatMessage("Author Name: "..author,"WHISPER", "Common","Punkyn")
	
	-- roll me phase
	elseif author == UnitName("player") and strlower(strsub(message, 1, 7)) == "!rollme" then
		
		if not BidMeFrame:IsVisible() then
			BidMe:ToggleShow()
		end
		
		-- make sure bidding is not paused right now.
		BidMe.db.profile.pause = false
		-- set the default values again incase they were left from before
		local sName, sLink, iRarity, iLevel, iMinLevel, sType, sSubType, iStackCount = GetItemInfo(message);
		
		
		
		BidMe:ResetVariables()
		-- reset the bidding window
		ScrollChildHTML:SetText("");
		ScrollFrame:UpdateScrollChildRect();
		
		BidMe.active = true
		BidMe.item_link = sLink

		BidMe.bid_level = 0 -- gone to rolls
		BidMebtnRemove:Disable()
		-- Need to initialize a list of raid members
		BidMe:CreateRollList()
		-- move on to process rolls
		BidMe.close_bids_in = 10
		BidMe.enable_rolls = true
				
		BidMe:SendMessage("** ROLLS **.")
		BidMetxtBidLevel:SetText("ROLLS")  

		if BidMe.db.profile.auto_advance then
			BidMe:Print("** AUTO MODE **")
		else
			BidMe:Print("** MANUAL MODE **")
		end
		--if(BidMe.db.profile.force_bid_command) then
		--	BidMe:SendMessage("Whisper me !bid <dkp amount> to bid.") 
		--end
		if BidMe.db.profile.auto_advance then
			BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))
		end
	end 
end

function BidMe:ProcessSystemMessage(arg1,arg2, arg3)

	local message = arg1
	local author = arg2
	local language = arg3	
	local player, roll, min_roll, max_roll, report, startIndex, endIndex
	
	if BidMe.enable_rolls and string.find(message, BidMe.ROLL_PATTERN) then
		_, _, player, roll, min_roll, max_roll = string.find(message, BidMe.ROLL_PATTERN)
        
        -- add class to the frame
        localizedClass, englishClass = UnitClass(player)
		
		roll = tonumber(roll)
		min_roll = tonumber(min_roll)
		max_roll = tonumber(max_roll)
		
		-- check for valid roll 
		if min_roll == 1 and max_roll == 100 then
			-- check to see if they have rolled once already
			if BidMe.roll_list[player] == 1 then
				-- post system message of a double roll by someone
				BidMe:Print(player.." has tried to roll more the once")
			else
				-- check to see if this roll is higher
--				local t = {roll=roll, name=player}
--				table.insert(BidMe.roll_list, 1, t)
				if BidMe.recorded_roll_list[1] == nil then
					table.insert(BidMe.recorded_roll_list, 1, {roll, player, localizedClass})
					BidMe.close_bids_in = 10
				else
					local i = 1
					while (BidMe.recorded_roll_list[i] ~= nil) and (BidMe.recorded_roll_list[i][1] >= roll) do i = i+1 end
					if i == 1 then
						BidMe.close_bids_in = 10
					end
					table.insert(BidMe.recorded_roll_list, i, {roll, player, localizedClass})
				end
				BidMe:FormUpdateRolls()
				BidMe.roll_list[player] = 1
				BidMe:SendWhisper("Your roll of "..roll.." has been recorded", player)
				
			end
		end
	end	
end


function BidMe:BIDME_RUN_COUNTDOWN()
	
	local local_bid_notice = ""
	local local_item_link = ""
	if BidMe.item_link ~= nil then
		local_item_link = BidMe.item_link..": "
	end

	if BidMe.close_bids_in == 0 then
		-- close primary bids
		if BidMe.bid_level == 3 then
			if BidMe.bid_list[1] ~= nil then
				-- we have a bid at this level, lets close it
				BidMe:BIDME_CLOSE_BID()
			else
				-- no bids so we go to the next lower level
				BidMe.bid_level = 2 -- go to initate / offspec bids
				BidMe:SendMessage("** No Primary Bids Received **.") 
				BidMe:SendMessage("** INITIATE / OFF SPEC BIDS **.") 
				BidMetxtBidLevel:SetText("INIT / OFF SPEC")
				--if(BidMe.db.profile.force_bid_command) then
				--	BidMe:SendMessage("Whisper me !bid <dkp amount> to bid.") 
				--end
				BidMe.close_bids_in = 10
				if BidMe.db.profile.auto_advance then
					BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))
				end
			end
		elseif BidMe.bid_level == 2 then
			if BidMe.bid_list[1] ~= nil then
				
				-- we have a bid at this level, lets close it
				BidMe:BIDME_CLOSE_BID()
			else
				BidMe.bid_level = 1 -- go to open bids
				BidMe:SendMessage("** No Initiate / Off Spec Bids Received **.") 
				BidMe:SendMessage("** OPEN BIDS **.")
				BidMetxtBidLevel:SetText("OPEN") 
				--if(BidMe.db.profile.force_bid_command) then
				--	BidMe:SendMessage("Whisper me !bid <dkp amount> to bid.") 
				--end
				BidMe.close_bids_in = 10
				if BidMe.db.profile.auto_advance then
					BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))		
				end
			end
		elseif BidMe.bid_level == 1 then
			if BidMe.bid_list[1] ~= nil then
				-- we have a bid at this level, lets close it
				BidMe:BIDME_CLOSE_BID()
			else
				BidMe.bid_level = 0 -- gone to rolls
				BidMebtnRemove:Disable()
				BidMe:SendMessage("** ROLLS **.")
				BidMetxtBidLevel:SetText("ROLLS")  


				-- Need to initialize a list of raid members
				BidMe:CreateRollList()

				
				-- move on to process rolls
				BidMe.close_bids_in = 10
				BidMe.enable_rolls = true
				if BidMe.db.profile.auto_advance then
					BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))		
				end
			end
		elseif BidMe.bid_level == 0 then

				-- close off all the rolls here
				BidMe:BIDME_CLOSE_ROLLS()

		end
	elseif BidMe.close_bids_in == 10 then
		if BidMe.enable_rolls then
			if BidMe.recorded_roll_list[1] ~= nil then
				local_bid_notice = BidMe.recorded_roll_list[1][1]
			else
				local_bid_notice = "No Rolls"
			end
		elseif BidMe.bid_list[1] == nil then
			local_bid_notice = "No Bids"
		else
			local_bid_notice = BidMe.bid_list[1]["bid"]	
		end
		BidMe:SendMessage(local_item_link..local_bid_notice.." - Going Once")
		BidMe.close_bids_in = 5
		if BidMe.db.profile.auto_advance then
			BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", 5)
		end
	elseif BidMe.close_bids_in == 5 then
		if BidMe.enable_rolls then
			if BidMe.recorded_roll_list[1] ~= nil then
				local_bid_notice = BidMe.recorded_roll_list[1][1]
			else
				local_bid_notice = "No Rolls"
			end
		elseif BidMe.bid_list[1] == nil then
			local_bid_notice = "No Bids"
		else
			local_bid_notice = BidMe.bid_list[1]["bid"]	
		end
		BidMe:SendMessage(local_item_link..local_bid_notice.." - Going Twice")
		BidMe.close_bids_in = 0
		if BidMe.db.profile.auto_advance then
			BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", 5)
		end
	end

end

function BidMe:BIDME_CLOSE_BID()
	if BidMe.bid_list[1] ~= nil then
		-- BidMe:SendMessage("Bidding Has Closed")
		BidMe:SendMessage("The winner is: "..BidMe.bid_list[1]["name"].." at a bid of "..BidMe.bid_list[1]["bid"])
		
		-- reset bidding data to make sure we dont process anything else
		BidMe.bid_list = {}
		BidMe.item_link = ""
		BidMe.active = false
		BidMe.bid_level = 3
		BidMe.close_bids_in = 10	
	else 
--		BidMe:SendMessage("*** No bids received ***")	
	end	
end

function BidMe:BIDME_CLOSE_ROLLS()

	-- check for tie roll on the top end
	if table.getn(BidMe.recorded_roll_list) > 1 then
		-- we have more then one roll so we have to check for a possible tie
		local i = 1
		local j = 2
		local bid_count = 0
		while (BidMe.recorded_roll_list[i][1] == BidMe.recorded_roll_list[j][1]) do 
			i = i+1 
			j = j+1 			
			bid_count = bid_count + 1
		end
		if bid_count == 0 then
			-- we have one top bid
			BidMe:SendMessage("Top Roll: "..BidMe.recorded_roll_list[1][1].." by "..BidMe.recorded_roll_list[1][2])	
		else
			-- more then one top bid
		
			BidMe:SendMessage("We have a tied top roll of: "..BidMe.recorded_roll_list[1][1])
			for x=bid_count+1,1,-1 do
				BidMe:SendMessage(BidMe.recorded_roll_list[x][2])
			end
		end

	elseif table.getn(BidMe.recorded_roll_list) == 1 then
		-- announce the single roll winner
		BidMe:SendMessage("Top Roll: "..BidMe.recorded_roll_list[1][1].." by "..BidMe.recorded_roll_list[1][2])	
    else
		-- no rolls
        BidMe:Print("** NO ROLLS RECEIVED **")
		BidMe:SendMessage("** NO ROLLS RECEIVED **")	
	end

	-- reset our variables for next item
	BidMebtnRemove:Enable()
	BidMe:CancelAllScheduledEvents()
	BidMe.ResetVariables()

end

function BidMe:CHAT_MSG_RAID(arg1, arg2, arg3)
	-- Called on each raid chat message to start bidding
	BidMe:ProcessChatMessage(arg1, arg2, arg3)
end

function BidMe:CHAT_MSG_PARTY(arg1, arg2, arg3)
	-- Called on each party chat message to start bidding
	BidMe:ProcessChatMessage(arg1, arg2, arg3)
end

function BidMe:CHAT_MSG_SAY(arg1, arg2, arg3)
	-- Called on each raid chat message to start bidding
	BidMe:ProcessChatMessage(arg1, arg2, arg3)
end

function BidMe:CHAT_MSG_RAID_LEADER(arg1, arg2, arg3)
	-- Called on each raid chat message to start bidding
	BidMe:ProcessChatMessage(arg1, arg2, arg3)
end

-- rolls options
function BidMe:CHAT_MSG_SYSTEM( arg1, arg2, arg3)
	BidMe:ProcessSystemMessage(arg1, arg2, arg3)
end
-----------------------------------

------------------------------------
function BidMe:Show_Love()
    if(math.random(100) == 100) then
        BidMe:SendMessage("I'm sorry everyone, but I must confess my undying love and admiration for DrMcNasty.")
    end
end






------------------------------------
function BidMe:CHAT_MSG_WHISPER(arg1, arg2, arg3)

	-- check to make sure we are activley taking bids
	if BidMe.active and not BidMe.enable_rolls then

        BidMe:Show_Love()
        
		local message = arg1
		local author = arg2
		local language = arg3
		
		local bid_amoumt_sub 
		local bid_amount
		
		-- check to make sure this is a bid and not spam message
		if strlower(strsub(message, 1, 4)) == "!bid" or tonumber(message) ~= nil then

			if strlower(strsub(message, 1, 4)) == "!bid" then
				bid_amoumt_sub = strsub(message, 5)
				bid_amount = tonumber(bid_amoumt_sub)
			elseif tonumber(message) ~= nil then
				bid_amount = tonumber(message)
			end 
			-- collect the bid amount
			-- check to see if this bid is higher then the previous one
			bid_amount = floor(bid_amount)

		-- Hey Trisha, your lawn on flooding?
		-- That's what she said.

			-- hack since I can't test against what isn't there
			local current_bid = 0
			if BidMe.bid_list[1] ~= nil then
				current_bid = BidMe.bid_list[1]["bid"]
			end

			if bid_amount > current_bid and bid_amount < 999 then
                
                localizedClass, englishClass = UnitClass(author)
				local t = {bid=bid_amount, name=author, class=localizedClass}
				table.insert(BidMe.bid_list, 1, t)

				--BidMe:Print(BidMe.bid_list[1]["bid"])
				
				-- update the GUI
				BidMe:FormUpdate()
				if BidMe.db.profile.whisper_response == true then
					BidMe:SendWhisper("You are the higest bidder with a bid of "..bid_amount, author)
				end				
				-- Notify the raid of the new high bid
				BidMe:SendMessage("New High Bid: "..bid_amount)
				-- Calncel and restart timers
				BidMe.close_bids_in = 10
				if BidMe.db.profile.auto_advance then
					BidMe:CancelAllScheduledEvents()
					BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))
				end
			elseif bid_amount <= current_bid then
				-- bid value was lower then current high bid
				-- notify the bidder
				BidMe:SendWhisper("Your bid of "..bid_amount.." was not high enough", author)
				BidMe:SendWhisper("Current Bid is "..BidMe.bid_list[1]["bid"]..".  You must bid more then this.", author)
			else
				BidMe:SendWhisper("You're an ass clown.  Why would you bid "..bid_amount.."?", author)
			end
		end
	end
end


function BidMe:FormUpdate()
	
	local window_text = ""

	for k,v in pairs(BidMe.bid_list) do 
		--for bid,name in pairs(v) do 
		window_text = window_text..v["bid"].." : "..v["name"].."("..v["class"]..")".."\n"	
--		BidMe:Print(v["bid"].." -> "..v["name"])
--		end
	end
--	BidMe.Print(window_text)
	
	--	for i = # BidMe.bid_list, 1, -1 do
		
--	end
	ScrollChildHTML:SetText(window_text);
	ScrollFrame:UpdateScrollChildRect();	
--	ScrollChildText:SetText(window_text)
end

function BidMe:FormUpdateRolls()
	
	local window_text = ""

	for k,v in pairs(BidMe.recorded_roll_list) do 
		--for bid,name in pairs(v) do 
		window_text = window_text..v[1].." : "..v[2].."("..v[3]..")".."\n"	
--		BidMe:Print(v["bid"].." -> "..v["name"])
--		end
	end
--	BidMe.Print(window_text)
	
	--	for i = # BidMe.bid_list, 1, -1 do
		
--	end
	ScrollChildHTML:SetText(window_text);
	ScrollFrame:UpdateScrollChildRect();	
--	ScrollChildText:SetText(window_text)
end

function BidMe:FormClear()
	ScrollChildHTML:SetText("");
	ScrollFrame:UpdateScrollChildRect();	
end

function BidMe:KickTopBid()

	-- check to see if we are in rolls
	if BidMe.enable_rolls then
		BidMe:Print("You can't kick a roll dumbass")

	elseif BidMe.bid_list[1] ~= nil then
		-- remove the top bid
		BidMe:SendMessage("High Bid Removed")
	
		table.remove(BidMe.bid_list,1)
		if BidMe.bid_list[1] == nil then
			BidMe:SendMessage("No Current Bids")	
			BidMe:FormClear()
		else
			BidMe:FormUpdate()
			-- update the bidders
			BidMe:SendMessage("New High Bid: "..BidMe.bid_list[1]["bid"])	
			BidMe:SendWhisper("Your bid of "..BidMe.bid_list[1]["bid"].." is again the top bid", BidMe.bid_list[1]["name"])	
		end
		BidMe.close_bids_in = 10
		if BidMe.db.profile.auto_advance then
			BidMe:CancelAllScheduledEvents()
			BidMe:ScheduleEvent("BIDME_RUN_COUNTDOWN", tonumber(BidMe.db.profile.countdown_timer))
		end	
	end
 
end
--------------------------------------------------------
-- Start roll code

function BidMe:CreateRollList()
	
	--setting up a list of people who are in the players group/raid and "have" to roll
	if(GetNumRaidMembers() > 0) then
		local raidMemberString = "raid"
		for i = 1, GetNumRaidMembers(), 1 do
			raidMemberString = "raid" --reset string		
			raidMemberString = raidMemberString .. i --add the suffix of corresponding player
			table.insert(BidMe.roll_list, (UnitName(raidMemberString)))
		end
	elseif(GetNumPartyMembers() > 0) then
		local partyMemberString = "party"
		for i = 1, GetNumPartyMembers(), 1 do
			partyMemberString = "party" --reset string		
			partyMemberString = partyMemberString .. i --add the suffix of corresponding player
			table.insert(BidMe.roll_list, (UnitName(partyMemberString)))
		end
	end
	
	-- reset the rolls list
	BidMe.rolls = {}
	
end

